/* stata do-file for replication of all models in tables 1, 4 and 6 of "The Politics of EU Eastern Enlargement: 
Evidence from a Heckman Selection Model" by Thomas Plmper, Christina J. Schneider and Vera E. Troeger*/

/* all variables used are labeled in the stata data set EUenlargement_replication.dta */


set mem 10000
set more off
set mat 800

cd c:\        /* specify the working directory where you have put the data set and want to save the results */

use EUenlargement_replication.dta

log using EUenlargement_replication.log, replace


/* Models 1 to 5 of table 1 test the main hypothesis of the paper*/

* table 1, Model 1:
heckprob accneg lag_chapter lag_oppcoal, select ( euapp=  lag_regqual lag_democ) first nocon


* table 1, Model 2:
heckprob accneg lag_chapter lag_oppcoal, select ( euapp=  lag_regqual lag_democ lag_pres1 lagexp_wdi02 laggovcons_wdi02) first nocon


* table 1, Model 3:
heckprob accneg lag_chapter lag_opp lagagrtot_mrd, select ( euapp=  lag_regqual lag_democ lag_pres1 lagexp_wdi02 laggovcons_wdi02) first nocon


* table 1, Model 4:
heckprob accneg lag_chapter lag_opp lagagrtot_mrd, select ( euapp=  lag_regqual lag_democ lag_pres1 lagexp_wdi02 laggovcons_wdi02 runy1) first nocon


* table 1, Model 5:
heckprob accneg lag_chapter lag_opp lagagrtot_mrd lag_democ, select ( euapp=  lag_regqual lag_democ lag_pres1 lagexp_wdi02 laggovcons_wdi02) first nocon


/* Models 1 to 5 of table 4 adjust for possibly correlated errors*/

* table 4, Model 1:
heckprob accneg_newcode lag_chapter lag_oppcoal, select ( euapp=  lag_regqual lag_democ) first nocon


* table 4, Model 2:
heckprob accneg_newcode lag_chapter lag_oppcoal, select ( euapp=  lag_regqual lag_democ lag_pres1 lagexp_wdi02 laggovcons_wdi02) first nocon


* table 4, Model 3:
heckprob accneg_newcode lag_chapter lag_opp lagagrtot_mrd, select ( euapp=  lag_regqual lag_democ lag_pres1 lagexp_wdi02 laggovcons_wdi02) first nocon


* table 4, Model 4:
heckprob accneg_newcode lag_chapter lag_opp lagagrtot_mrd, select ( euapp=  lag_regqual lag_democ lag_pres1 lagexp_wdi02 laggovcons_wdi02 runy1) first nocon


* table 4, Model 5:
heckprob accneg_newcode lag_chapter lag_opp lagagrtot_mrd lag_democ, select ( euapp=  lag_regqual lag_democ lag_pres1 lagexp_wdi02 laggovcons_wdi02) first nocon


/* Models 1 and 2 of table 6 test for endogeneity*/

* table 6, Model 1:
nbreg chapter nsh1 oppcoal democ if euapp==1, nocon robust

* table 6, Model 2:
nbreg chapter nsh1 oppcoal agrtot_mrd democ if euapp==1, nocon robust


log close
